@@ -1,6 +1,10 @@
 #ifndef CORBA_CONTEXT_TYPE_H
 #define CORBA_CONTEXT_TYPE_H 1
 
+#include <glib.h>
+
+G_BEGIN_DECLS
+
 #ifdef ORBIT2_INTERNAL_API
 
 typedef struct {
@@ -10,4 +14,6 @@ typedef struct {
 
 #endif /* ORBIT2_INTERNAL_API */
 
+G_END_DECLS
+
 #endif
