@@ -61,7 +61,7 @@ typedef struct {
 } TkInfo;
 
 #define DEF_TC_BASIC(nom, c_align)                                      \
-	const struct CORBA_TypeCode_struct TC_CORBA_##nom##_struct = {  \
+	ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_##nom##_struct = { \
 		{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},           \
 		CORBA_tk_##nom,                                         \
 		0, 0, c_align,						\
@@ -78,13 +78,13 @@ typedef struct {
 #define CORBA_tk_unsigned_short CORBA_tk_ushort
 #define CORBA_tk_long_double CORBA_tk_longdouble
 
-const struct CORBA_TypeCode_struct TC_null_struct = {
+ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_null_struct = {
 	{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
 	CORBA_tk_null, 0, 0, -1, 0, 0, NULL,
 	CORBA_OBJECT_NIL, "null", "IDL:omg.org/CORBA/Null:1.0"
 };
 
-const struct CORBA_TypeCode_struct TC_void_struct = {
+ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_void_struct = {
 	{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
 	CORBA_tk_void, 0, 0, -1, 0, 0, NULL,
 	CORBA_OBJECT_NIL, "void", "IDL:omg.org/CORBA/void:1.0"
@@ -688,7 +688,7 @@ typecode_equiv_internal (CORBA_TypeCode obj,
 
 CORBA_boolean
 CORBA_TypeCode_equal (CORBA_TypeCode obj,
-		      CORBA_TypeCode tc,
+		      const CORBA_TypeCode tc,
 		      CORBA_Environment *ev)
 {
 	return typecode_equiv_internal (obj, tc, TRUE, ev);
@@ -696,7 +696,7 @@ CORBA_TypeCode_equal (CORBA_TypeCode obj,
 
 CORBA_boolean
 CORBA_TypeCode_equivalent (CORBA_TypeCode obj,
-			   CORBA_TypeCode tc,
+			   const CORBA_TypeCode tc,
 			   CORBA_Environment *ev)
 {
 	return typecode_equiv_internal (obj, tc, FALSE, ev);
@@ -786,7 +786,7 @@ CORBA_TypeCode_member_count (CORBA_TypeCode     typecode,
 
 CORBA_Identifier
 CORBA_TypeCode_member_name (CORBA_TypeCode       typecode,
-			    CORBA_unsigned_long  index,
+			    const CORBA_unsigned_long index,
 			    CORBA_Environment   *ev)
 {
 	if (!(typecode->kind == CORBA_tk_struct ||
@@ -812,7 +812,7 @@ CORBA_TypeCode_member_name (CORBA_TypeCode       typecode,
 
 CORBA_TypeCode
 CORBA_TypeCode_member_type (CORBA_TypeCode       typecode,
-			    CORBA_unsigned_long  index,
+			    const CORBA_unsigned_long index,
 			    CORBA_Environment   *ev)
 {
 	if (!(typecode->kind == CORBA_tk_struct ||
@@ -838,7 +838,7 @@ CORBA_TypeCode_member_type (CORBA_TypeCode       typecode,
 
 CORBA_any *
 CORBA_TypeCode_member_label (CORBA_TypeCode       typecode,
-			     CORBA_unsigned_long  index,
+			     const CORBA_unsigned_long index,
 			     CORBA_Environment   *ev)
 {
 	CORBA_any *retval;
@@ -1070,7 +1070,7 @@ static const TkInfo tk_info[CORBA_tk_last]= {
 	{ TK_SIMPLE, tc_enc_tk_fixed, tc_dec_tk_fixed} /* tk_fixed */
 };
 
-const ORBit_RootObject_Interface ORBit_TypeCode_epv = {
+ORBIT2_MAYBE_CONST ORBit_RootObject_Interface ORBit_TypeCode_epv = {
 	ORBIT_ROT_TYPECODE,
 	ORBit_TypeCode_free_fn
 };
@@ -1098,7 +1098,7 @@ tc_dec (CORBA_TypeCode  *t,
 
 		if (lkind != CORBA_tk_recursive) {
 			g_warning ("%s: invalid CORBA_TCKind, lkind=%lu",
-				   G_GNUC_FUNCTION, (unsigned long int) lkind);
+				   G_STRFUNC, (unsigned long int) lkind);
 			return TRUE;
 		}
 
