@@ -1,6 +1,12 @@
+#include <config.h>
 #include <string.h>
 #include <stdlib.h>
-#include <unistd.h>
+#ifdef HAVE_UNISTD_H
+#  include <unistd.h>
+#endif
+#ifdef _WIN32
+#  include <process.h>
+#endif
 #include <stdarg.h>
 
 #include <orbit/orbit.h>
